@@ -45,7 +45,7 @@ Report bugs to the Bioperl bug tracking system to help us keep track
 the bugs and their resolution.  Bug reports can be submitted via the
 web:
 
-  https://redmine.open-bio.org/projects/bioperl/
+  https://github.com/bioperl/bioperl-live/issues
 
 =head1 AUTHORS - Peter Schattner
 
@@ -119,11 +119,7 @@ sub next_aln {
 	};
     }
 
-    # return 0 if scalar @names < 1;
-    if (scalar(@names) < 1) {
-	undef $aln;
-	return $aln;
-    }
+    return if @names < 1;
 
     # now got this as a name - sequence hash. Let's make some sequences!
 
