@@ -1,7 +1,7 @@
 #
 # BioPerl module for Bio::Index::BlastTable
 #
-# Please direct questions and support issues to <bioperl-l@bioperl.org> 
+# Please direct questions and support issues to <bioperl-l@bioperl.org>
 #
 # Cared for by Chris Fields <cjfields@uiuc.edu>
 #
@@ -70,15 +70,15 @@ the Bioperl mailing list.  Your participation is much appreciated.
   bioperl-l@bioperl.org                  - General discussion
   http://bioperl.org/wiki/Mailing_lists  - About the mailing lists
 
-=head2 Support 
+=head2 Support
 
 Please direct usage questions or support issues to the mailing list:
 
 I<bioperl-l@bioperl.org>
 
-rather than to the module maintainer directly. Many experienced and 
-reponsive experts will be able look at the problem and quickly 
-address it. Please include a thorough description of the problem 
+rather than to the module maintainer directly. Many experienced and
+reponsive experts will be able look at the problem and quickly
+address it. Please include a thorough description of the problem
 with code and data examples if at all possible.
 
 =head2 Reporting Bugs
@@ -122,7 +122,7 @@ sub _version {
                 -verbose     => 0);
 
   Function: Returns a new index object.  If filename is
-            specified, then open_dbm() is immediately called. 
+            specified, then open_dbm() is immediately called.
             Bio::Index::Abstract->new() will usually be called
             directly only when opening an existing index.
   Returns : A new index object
@@ -149,7 +149,7 @@ sub new {
 
  Title   : fetch_report
  Usage   : my $blastreport = $idx->fetch_report($id);
- Function: Returns a Bio::SearchIO report object 
+ Function: Returns a Bio::SearchIO report object
            for a specific blast report
  Returns : Bio::SearchIO
  Args    : valid id
@@ -177,9 +177,9 @@ sub fetch_report{
   Function: Specialist function to index BLAST report file(s).
             Is provided with a filename and an integer
             by make_index in its SUPER class.
-  Example : 
-  Returns : 
-  Args    : 
+  Example :
+  Returns :
+  Args    :
 
 =cut
 
@@ -213,7 +213,7 @@ sub _index_file {
             }
             next
         }
-        
+
         if (/^(?:([^\t]+)\t)(?:[^\t]+\t){7,}/) {
             next if $last_query eq $1;
             $indexpoint = tell($BLAST) - length($_) - $correction unless $is_m9;
@@ -235,7 +235,7 @@ sub _index_file {
   Function: Stores or returns the code used by record_id to
             parse the ID for record from a string.  Useful
             for (for instance) specifying a different
-            parser for different flavours of blast dbs. 
+            parser for different flavours of blast dbs.
             Returns \&default_id_parser (see below) if not
             set. If you supply your own id_parser
             subroutine, then it should expect a fasta
@@ -297,7 +297,7 @@ sub default_id_parser
  Usage   : $value = $self->write_flag();
            $self->write_flag($value);
  Function: Gets or sets the value of write_flag, which
-           is wether the dbm file should be opened with
+           is whether the dbm file should be opened with
            write access.
  Returns : The current value of write_flag (default 0)
  Args    : Value of write_flag if setting, or none if
@@ -308,11 +308,11 @@ sub default_id_parser
  Usage   : $value = $self->dbm_package();
            $self->dbm_package($value);
 
- Function: Gets or sets the name of the Perl dbm module used. 
+ Function: Gets or sets the name of the Perl dbm module used.
            If the value is unset, then it returns the value of
            the package variable $USE_DBM_TYPE or if that is
            unset, then it chooses the best available dbm type,
-           choosing 'DB_File' in preference to 'SDBM_File'. 
+           choosing 'DB_File' in preference to 'SDBM_File'.
            Bio::Abstract::Index may work with other dbm file
            types.
 
@@ -329,10 +329,10 @@ sub default_id_parser
            at the approprite place
 
            This provides for a way to get the actual
-           file contents and not an object 
+           file contents and not an object
 
            WARNING: you must parse the record deliminter
-           *yourself*. Abstract wont do this for you 
+           *yourself*. Abstract won't do this for you
            So this code
 
            $fh = $index->get_stream($myid);
@@ -349,7 +349,7 @@ sub default_id_parser
 
  Returns : A filehandle object
  Args    : string represents the accession number
- Notes   : This method should not be used without forethought 
+ Notes   : This method should not be used without forethought
 
 
 =head2 open_dbm
@@ -359,7 +359,7 @@ sub default_id_parser
             object.  Write access is only given if explicitly
             asked for by calling new(-write => 1) or having set
             the write_flag(1) on the index object.  The type of
-            dbm file opened is that returned by dbm_package(). 
+            dbm file opened is that returned by dbm_package().
             The name of the file to be is opened is obtained by
             calling the filename() method.
 
@@ -375,8 +375,8 @@ sub default_id_parser
             index module.  Used to permanently identify an index
             file as having been created by a particular version
             of the index module.  Must be provided by the sub class
-  Example : 
-  Returns : 
+  Example :
+  Returns :
   Args    : none
 
 =head2 _filename
@@ -384,9 +384,9 @@ sub default_id_parser
   Title   : _filename
   Usage   : $index->_filename( FILE INT )
   Function: Indexes the file
-  Example : 
-  Returns : 
-  Args    : 
+  Example :
+  Returns :
+  Args    :
 
 =head2 _file_handle
 
@@ -409,7 +409,7 @@ sub default_id_parser
             track the number of files indexed.  Sets or gets
             the number of files indexed when called with or
             without an argument.
-  Example : 
+  Example :
   Returns : INT
   Args    : INT
 
@@ -433,7 +433,7 @@ sub default_id_parser
   Usage   : $packed_string = $index->pack_record( LIST )
   Function: Packs an array of scalars into a single string
             joined by ASCII 034 (which is unlikely to be used
-            in any of the strings), and returns it. 
+            in any of the strings), and returns it.
   Example : $packed_string = $index->pack_record( $fileNumber, $begin, $end )
   Returns : STRING or undef
   Args    : LIST
