@@ -198,13 +198,14 @@ sub matrix_name{
 =head2 entry
 
  Title   : entry
- Usage   : my $entry = $matrix->entry($row,$col)
+ Usage   : my $entry = $matrix->entry($row,$col,$value)
  Function: Get the value for a specific cell as specified
            by the row and column names
  Returns : scalar value or undef if row or col does not
            exist
  Args    : $rowname - name of the row
            $colname - column name
+           $value   - [optional] New value for the entry
 
 =cut
 
@@ -222,11 +223,12 @@ sub entry{
 =head2 get_entry
 
  Title   : get_entry
- Usage   : my $entry = $matrix->get_entry($rowname,$columname)
+ Usage   : my $entry = $matrix->get_entry($rowname,$columname,$value)
  Function: Get the entry for a given row,column pair
  Returns : scalar
  Args    : $row name
            $column name 
+           $value
 
 
 =cut
