@@ -195,7 +195,7 @@ sub next_psm {
 
 	if ($line !~ /[^ACGTacgt]/g) {
 	    # This is a set of aligned sequences
-	    $self->throw("Mixing between types is not allowed or a parsing error occured\n") 
+	    $self->throw("Mixing between types is not allowed or a parsing error occurred\n")
 		if (($self->{_mtype} != 3) && ($mtype)) ;
 	    $self->throw("Bad sequence- different length: $line\n") 
 		if (($len) && ($len!=length($line)));
@@ -209,12 +209,12 @@ sub next_psm {
 	    $line=~s/[\s\t]+/\t/g;
 	    my @data=split(/[\s\t]+/,$line);
 	    if ($#data==3) {
-		$self->throw("Mixing between types is not allowed or a parsing error occured\n") if (($mtype)&&($self->{_mtype} !=1)) ;
+		$self->throw("Mixing between types is not allowed or a parsing error occurred\n") if (($mtype)&&($self->{_mtype} !=1)) ;
 		$self->{_mtype}=1;
 		$mtype=1;
 	    }
 	    else   {
-		$self->throw("Mixing between types is not allowedor a parsing error occured\n") if (($mtype)&&($self->{_mtype} !=2)) ;
+		$self->throw("Mixing between types is not allowedor a parsing error occurred\n") if (($mtype)&&($self->{_mtype} !=2)) ;
 		$self->{_mtype}=2;
 		$mtype=1;
 	    }
