@@ -1,10 +1,11 @@
-# $Id: dagflat.pm 11671 2007-08-30 18:46:39Z cjfields $
 #
 # BioPerl module for Bio::OntologyIO::dagflat
 #
+# Please direct questions and support issues to <bioperl-l@bioperl.org> 
+#
 # Cared for by Hilmar Lapp, hlapp at gmx.net
 #
-# (c) Christian M. Zmasek, czmasek@gnf.org, 2002.
+# (c) Christian M. Zmasek, czmasek-at-burnham.org, 2002.
 # (c) Hilmar Lapp, hlapp at gmx.net, 2003.
 # (c) GNF, Genomics Institute of the Novartis Research Foundation, 2002.
 #
@@ -59,21 +60,32 @@ Bioperl mailing lists  Your participation is much appreciated.
   bioperl-l@bioperl.org                  - General discussion
   http://bioperl.org/wiki/Mailing_lists  - About the mailing lists
 
+=head2 Support 
+
+Please direct usage questions or support issues to the mailing list:
+
+I<bioperl-l@bioperl.org>
+
+rather than to the module maintainer directly. Many experienced and 
+reponsive experts will be able look at the problem and quickly 
+address it. Please include a thorough description of the problem 
+with code and data examples if at all possible.
+
 =head2 Reporting Bugs
 
 Report bugs to the Bioperl bug tracking system to help us keep track
 the bugs and their resolution.  Bug reports can be submitted via the
 web:
 
-  http://bugzilla.open-bio.org/
+  https://github.com/bioperl/bioperl-live/issues
 
 =head1 AUTHOR
 
 Christian M. Zmasek
 
-Email: czmasek@gnf.org  or  cmzmasek@yahoo.com
+Email: czmasek-at-burnham.org  or  cmzmasek@yahoo.com
 
-WWW:   http://www.genetics.wustl.edu/eddy/people/zmasek/
+WWW:   http://monochrome-effect.net/
 
 Address:
 
