@@ -69,7 +69,7 @@ Report bugs to the Bioperl bug tracking system to help us keep track
 of the bugs and their resolution. Bug reports can be submitted via
 the web:
 
-  https://redmine.open-bio.org/projects/bioperl/
+  https://github.com/bioperl/bioperl-live/issues
 
 =head1 AUTHOR - Pedro M. Gomez-Fabre
 
@@ -172,8 +172,8 @@ sub haplotype_block{
 
  Title   : input_block 
  Usage   : $obj->input_block()
- Function: returns haplotype block. By now will produce the same ouput than
-           $self->haplotype_block. but for compatiblity, this method is kept. 
+ Function: returns haplotype block. By now will produce the same output than
+           $self->haplotype_block. but for compatibility, this method is kept.
            This method is deprecated.
  Returns : reference to array of array with the haplotype input value 
  Args    : none 
@@ -367,7 +367,7 @@ sub _generateCombinations{
  Usage   : internal
  Function: take the haplotype and a list of possible combination
            for that length. Generate a subset and scan it to find if
-           the information is enought to define the haplotype set.
+           the information is enough to define the haplotype set.
  Returns :
  Args    : none
  Status  : private
