@@ -281,7 +281,7 @@ sub accession {
  Usage   : $desc = $hit->description();
  Function: Retrieve the description for the hit
  Returns : a scalar string
- Args    : [optional] scalar string to set the descrition
+ Args    : [optional] scalar string to set the description
 
 =cut
 
