@@ -173,7 +173,7 @@ sub domains{ shift->hsps() }
  Usage   : $desc = $hit->description();
  Function: Retrieve the description for the hit
  Returns : a scalar string
- Args    : [optional] scalar string to set the descrition
+ Args    : [optional] scalar string to set the description
 
 =cut
 
