@@ -1,7 +1,7 @@
 #
 # BioPerl module for Bio::SeqFeature::AnnotationAdaptor
 #
-# Please direct questions and support issues to <bioperl-l@bioperl.org> 
+# Please direct questions and support issues to <bioperl-l@bioperl.org>
 #
 # Cared for by Hilmar Lapp <hlapp at gmx.net>
 #
@@ -17,7 +17,7 @@
 # Refer to the Perl Artistic License (see the license accompanying this
 # software package, or see http://www.perl.com/language/misc/Artistic.html)
 # for the terms under which you may use, modify, and redistribute this module.
-# 
+#
 # THIS PACKAGE IS PROVIDED "AS IS" AND WITHOUT ANY EXPRESS OR IMPLIED
 # WARRANTIES, INCLUDING, WITHOUT LIMITATION, THE IMPLIED WARRANTIES OF
 # MERCHANTIBILITY AND FITNESS FOR A PARTICULAR PURPOSE.
@@ -46,17 +46,17 @@ Bio::SeqFeature::AnnotationAdaptor - integrates SeqFeatureIs annotation
    $feat->annotation->add_Annotation("dbxref", $dblink);
 
    # to integrate tag/value annotation with AnnotationCollectionI
-   # annotation, use this adaptor, which also implements 
+   # annotation, use this adaptor, which also implements
    # Bio::AnnotationCollectionI
    my $anncoll = Bio::SeqFeature::AnnotationAdaptor->new(-feature => $feat);
 
-   # this will now return tag/value pairs as 
+   # this will now return tag/value pairs as
    # Bio::Annotation::SimpleValue objects
    my @anns = $anncoll->get_Annotations("mytag");
    # other added before annotation is available too
    my @dblinks = $anncoll->get_Annotations("dbxref");
 
-   # also supports transparent adding of tag/value pairs in 
+   # also supports transparent adding of tag/value pairs in
    # Bio::AnnotationI flavor
    my $tagval = Bio::Annotation::SimpleValue->new(-value => "some value",
                                                   -tagname => "some tag");
@@ -107,15 +107,15 @@ the Bioperl mailing list.  Your participation is much appreciated.
   bioperl-l@bioperl.org                  - General discussion
   http://bioperl.org/wiki/Mailing_lists  - About the mailing lists
 
-=head2 Support 
+=head2 Support
 
 Please direct usage questions or support issues to the mailing list:
 
 I<bioperl-l@bioperl.org>
 
-rather than to the module maintainer directly. Many experienced and 
-reponsive experts will be able look at the problem and quickly 
-address it. Please include a thorough description of the problem 
+rather than to the module maintainer directly. Many experienced and
+reponsive experts will be able look at the problem and quickly
+address it. Please include a thorough description of the problem
 with code and data examples if at all possible.
 
 =head2 Reporting Bugs
@@ -154,7 +154,7 @@ use base qw(Bio::Root::Root Bio::AnnotationCollectionI Bio::AnnotatableI);
 
  Title   : new
  Usage   : my $obj = Bio::SeqFeature::AnnotationAdaptor->new();
- Function: Builds a new Bio::SeqFeature::AnnotationAdaptor object 
+ Function: Builds a new Bio::SeqFeature::AnnotationAdaptor object
  Returns : an instance of Bio::SeqFeature::AnnotationAdaptor
  Args    : Named parameters
             -feature    the Bio::SeqFeatureI implementing object to adapt
@@ -192,7 +192,7 @@ sub new {
  Usage   : $obj->feature($newval)
  Function: Get/set the feature that this object adapts to an
            AnnotationCollectionI.
- Example : 
+ Example :
  Returns : value of feature (a Bio::SeqFeatureI compliant object)
  Args    : new value (a Bio::SeqFeatureI compliant object, optional)
 
@@ -217,7 +217,7 @@ sub feature{
 
            If requested before having been set, the value will default to the
            annotation object of the feature if it has one.
- Example : 
+ Example :
  Returns : value of annotation (a Bio::AnnotationCollectionI compliant object)
  Args    : new value (a Bio::AnnotationCollectionI compliant object, optional)
 
@@ -254,7 +254,7 @@ sub annotation{
 sub get_all_annotation_keys{
     my ($self) = @_;
     my @keys = ();
-    
+
     # get the tags from the feature object
     if ($self->feature()->can('get_all_tags')) {
         push(@keys, $self->feature()->get_all_tags());
@@ -322,7 +322,7 @@ sub get_Annotations{
 
  Title   : get_num_of_annotations
  Usage   : my $count = $collection->get_num_of_annotations()
- Function: Returns the count of all annotations stored in this collection 
+ Function: Returns the count of all annotations stored in this collection
  Returns : integer
  Args    : none
 
@@ -376,14 +376,14 @@ sub get_num_of_annotations{
  Returns : none
  Args    : annotation key ('disease', 'dblink', ...)
            object to store (must be Bio::AnnotationI compliant)
-           [optional] object archetype to map future storage of object 
+           [optional] object archetype to map future storage of object
                       of these types to
 
 =cut
 
 sub add_Annotation{
     my ($self,$key,$object,$archetype) = @_;
-   
+
     # if there's no key we use the tagname() as key
     if(ref($key) && $key->isa("Bio::AnnotationI") &&
        (! ($object && ref($object)))) {
@@ -394,15 +394,15 @@ sub add_Annotation{
 	$self->throw("Annotation object must have a tagname if key omitted")
 	    unless $key;
     }
-    
+
     if( !defined $object ) {
 	$self->throw("Must have at least key and object in add_Annotation");
     }
-    
+
     if( ! (ref($object) && $object->isa("Bio::AnnotationI")) ) {
-	$self->throw("object must be a Bio::AnnotationI compliant object, otherwise we wont add it!");
+	$self->throw("object must be a Bio::AnnotationI compliant object, otherwise we won't add it!");
     }
-    
+
     # ready to add -- if it's a SimpleValue, we add to the feature's tags,
     # otherwise we'll add to the annotation collection implementation
 
@@ -453,7 +453,7 @@ sub remove_Annotations{
     foreach my $key (@keys) {
 	# delete the tag if it is one
 	$self->feature->remove_tag($key) if $self->feature->has_tag($key);
-	# and delegate to the annotation implementation 
+	# and delegate to the annotation implementation
 	my $anncoll = $self->annotation();
 	if($anncoll && $anncoll->can('remove_Annotations')) {
 	    $anncoll->remove_Annotations($key);
@@ -481,9 +481,9 @@ sub remove_Annotations{
            Bio::Annotation::SimpleValue in terms of supported
            arguments at creation time, and the methods.
 
- Example : 
+ Example :
  Returns : A Bio::Factory::ObjectFactoryI compliant object
- Args    : new value (a Bio::Factory::ObjectFactoryI compliant object, 
+ Args    : new value (a Bio::Factory::ObjectFactoryI compliant object,
            optional)
 
 
