@@ -97,7 +97,7 @@ Report bugs to the Bioperl bug tracking system to help us keep track
 of the bugs and their resolution. Bug reports can be submitted via
 the web:
 
-  https://redmine.open-bio.org/projects/bioperl/
+  https://github.com/bioperl/bioperl-live/issues
 
 =head1 AUTHOR - Stefan Kirov
 
@@ -196,7 +196,7 @@ sub next_seq {
 
     #Basic data
     #$xval->{summary}=~s/\n//g;
-    my $seq = Bio::Seq->new(
+    $seq = Bio::Seq->new(
         -display_id       => $xval->{gene}{locus},
         -accession_number => $xval->{'track-info'}{geneid},
         -desc             => $xval->{summary}
@@ -354,11 +354,21 @@ sub next_seq {
     }
 
     #Homology
-    my ( $uncapt, $hom, $anchor ) = _process_src( $xval->{homology}->{source} );
-    foreach my $homann (@$hom) {
-        $self->{_ann}->add_Annotation( 'dblink', $homann );
+    my @homologies; # Sometimes there are multiple entries
+    if (ref $xval->{homology} eq 'ARRAY') {
+        @homologies = @{ $xval->{homology} };
+    }
+    else {
+        push @homologies, $xval->{homology};
+    }
+
+    foreach my $homology (@homologies) {
+        my ( $uncapt, $hom, $anchor ) = _process_src( $homology->{source} );
+        foreach my $homann (@$hom) {
+            $self->{_ann}->add_Annotation( 'dblink', $homann );
+        }
+        push @alluncaptured, $uncapt;
     }
-    push @alluncaptured, $uncapt;
 
     #Index terms
     if (   ( exists( $xval->{'xtra-index-terms'} ) )
@@ -857,6 +867,7 @@ sub _process_locus {
         );
         $gseq->add_SeqFeature($nfeat);
     }
+
     my @products;
     if ( ref( $self->{_current}->{products} ) eq 'ARRAY' ) {
         @products = @{ $self->{_current}->{products} };
@@ -865,6 +876,7 @@ sub _process_locus {
         push @products, $self->{_current}->{products};
     }
     delete $self->{_current}->{products};
+
     my $gstruct = Bio::SeqFeature::Gene::GeneStructure->new();
     foreach my $product (@products) {
         my ( $tr, $uncapt ) =
@@ -890,8 +902,9 @@ sub _process_products_coordinates {
       || 0;    #In case it is not known: should there be an entry at all?
     my $end    = shift || 1;
     my $strand = shift || 1;
-    my ( @coords, @uncapt );
     return unless ( exists( $coord->{accession} ) );
+
+    my ( @coords, @uncapt );
     my $transcript = Bio::SeqFeature::Gene::Transcript->new(
         -primary => $coord->{accession},    #Desc is actually non functional...
         -start   => $start,
@@ -921,13 +934,24 @@ sub _process_products_coordinates {
             push @uncapt, $exon;
         }
     }
+
     my ( $prot, $uncapt );
     if ( exists( $coord->{products} ) ) {
-        my ( $prot, $uncapt ) =
-          _process_products_coordinates( $coord->{products},
-            $start, $end, $strand );
-        $transcript->add_SeqFeature($prot);
-        push @uncapt, $uncapt;
+        my @products; # Sometimes there are multiple entries
+        if (ref $coord->{products} eq 'ARRAY') {
+            @products = @{ $coord->{products} };
+        }
+        else {
+            push @products, $coord->{products};
+        }
+
+        foreach my $product (@products) {
+            my ( $prot, $uncapt ) =
+              _process_products_coordinates( $product,
+                $start, $end, $strand );
+            $transcript->add_SeqFeature($prot);
+            push @uncapt, $uncapt;
+        }
     }
     return $transcript, \@uncapt;
 }
